@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.108_03';
+our $VERSION = '0.108_04';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Mon Oct 15 14:03:09 2018 GMT
+# on Tue Oct 16 20:35:54 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1696,7 +1696,7 @@ __PACKAGE__->status( add => 24839, iridium => 'D', 'Iridium 10', 'Decayed 2018-1
 __PACKAGE__->status( add => 24840, iridium => 'D', 'Iridium 13', 'Decayed 2018-04-29' );
 __PACKAGE__->status( add => 24841, iridium => '-', 'Iridium 16', 'Tumbling' );
 __PACKAGE__->status( add => 24842, iridium => '-', 'Iridium 911', 'Tumbling' );
-__PACKAGE__->status( add => 24869, iridium => 'D', 'Iridium 15', 'Decayed 2018-10-15 per Kelso and Sladen' );
+__PACKAGE__->status( add => 24869, iridium => 'D', 'Iridium 15', 'Decayed 2018-10-14' );
 __PACKAGE__->status( add => 24870, iridium => '-', 'Iridium 17', 'Tumbling' );
 __PACKAGE__->status( add => 24871, iridium => '-', 'Iridium 920', 'Tumbling' );
 __PACKAGE__->status( add => 24872, iridium => 'D', 'Iridium 18', 'Decayed 2018-08-19' );
@@ -1732,7 +1732,7 @@ __PACKAGE__->status( add => 25105, iridium => '-', 'Iridium 24', 'Tumbling' );
 __PACKAGE__->status( add => 25106, iridium => 'D', 'Iridium 47', 'Decayed 2018-09-01' );
 __PACKAGE__->status( add => 25107, iridium => 'D', 'Iridium 48', 'Decayed 2001-05-05' );
 __PACKAGE__->status( add => 25108, iridium => 'D', 'Iridium 49', 'Decayed 2018-02-13' );
-__PACKAGE__->status( add => 25169, iridium => '+', 'Iridium 52', '' );
+__PACKAGE__->status( add => 25169, iridium => 'S', 'Iridium 52', '' );
 __PACKAGE__->status( add => 25170, iridium => 'D', 'Iridium 56', 'Decayed 2018-10-11' );
 __PACKAGE__->status( add => 25171, iridium => '+', 'Iridium 54', '' );
 __PACKAGE__->status( add => 25172, iridium => 'D', 'Iridium 50', 'Decayed 2018-09-23' );
@@ -1783,10 +1783,10 @@ __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
 __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-08-24' );
 
 # Summary:
-# Operational [+]: 9
-#       Spare [S]: 9
-#    Tumbling [-]: 37
-#     Decayed [D]: 42
+# Operational [+]: 8
+#       Spare [S]: 10
+#    Tumbling [-]: 36
+#     Decayed [D]: 43
 
 1;
 
